.. mmgroup documentation master file, created by
   sphinx-quickstart on Mon Feb 10 10:01:00 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to mmgroup's documentation!
===================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   api.rst
   guide.rst
   c_interface.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
